@@ -216,12 +216,13 @@ class CfgEntry
     };
 
     CfgEntry( const QString &group, const QString &type, const QString &key,
-              const QString &name, const QString &context, const QString &label,
-              const QString &toolTip, const QString &whatsThis, const QString &code,
+              const QString &name, const QString &labelContext, const QString &label,
+              const QString &toolTipContext, const QString &toolTip, const QString &whatsThisContext, const QString &whatsThis, const QString &code,
               const QString &defaultValue, const Choices &choices, const QList<Signal> signalList,
               bool hidden )
       : mGroup( group ), mType( type ), mKey( key ), mName( name ),
-        mContext( context ), mLabel( label ), mToolTip( toolTip ), mWhatsThis( whatsThis ),
+        mLabelContext( labelContext ), mLabel( label ), mToolTipContext( toolTipContext ), mToolTip( toolTip ),
+        mWhatsThisContext( whatsThisContext ), mWhatsThis( whatsThis ),
         mCode( code ), mDefaultValue( defaultValue ), mChoices( choices ),
         mSignalList(signalList), mHidden( hidden )
     {
@@ -239,15 +240,21 @@ class CfgEntry
     void setName( const QString &name ) { mName = name; }
     QString name() const { return mName; }
 
-    void setContext( const QString &context ) { mContext = context; }
-    QString context() const { return mContext; }
+    void setLabelContext( const QString &labelContext ) { mLabelContext = labelContext; }
+    QString labelContext() const { return mLabelContext; }
 
     void setLabel( const QString &label ) { mLabel = label; }
     QString label() const { return mLabel; }
 
+    void setToolTipContext( const QString &toolTipContext ) { mToolTipContext = toolTipContext; }
+    QString toolTipContext() const { return mToolTipContext; }
+
     void setToolTip( const QString &toolTip ) { mToolTip = toolTip; }
     QString toolTip() const { return mToolTip; }
 
+    void setWhatsThisContext( const QString &whatsThisContext ) { mWhatsThisContext = whatsThisContext; }
+    QString whatsThisContext() const { return mWhatsThisContext; }
+
     void setWhatsThis( const QString &whatsThis ) { mWhatsThis = whatsThis; }
     QString whatsThis() const { return mWhatsThis; }
 
@@ -296,7 +303,7 @@ class CfgEntry
       cerr << "  type: " << mType << endl;
       cerr << "  key: " << mKey << endl;
       cerr << "  name: " << mName << endl;
-      cerr << "  context: " << mContext << endl;
+      cerr << "  label context: " << mLabelContext << endl;
       cerr << "  label: " << mLabel << endl;
 // whatsthis
       cerr << "  code: " << mCode << endl;
@@ -320,9 +327,11 @@ class CfgEntry
     QString mType;
     QString mKey;
     QString mName;
-    QString mContext;
+    QString mLabelContext;
     QString mLabel;
+    QString mToolTipContext;
     QString mToolTip;
+    QString mWhatsThisContext;
     QString mWhatsThis;
     QString mCode;
     QString mDefaultValue;
@@ -527,7 +536,11 @@ static void preProcessDefault( QString &defaultValue, const QString &name,
       if (!code.isEmpty())
          cpp << endl;
 
-      cpp << "  QStringList default" << name << ";" << endl;
+      if( type == "UrlList" ) {
+        cpp << "  KUrl::List default" << name << ";" << endl;
+      } else {
+        cpp << "  QStringList default" << name << ";" << endl;
+      }
       const QStringList defaults = defaultValue.split(QLatin1Char(','));
       QStringList::ConstIterator it;
       for( it = defaults.constBegin(); it != defaults.constEnd(); ++it ) {
@@ -593,9 +606,11 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element, const Cf
   QString name = element.attribute( "name" );
   QString key = element.attribute( "key" );
   QString hidden = element.attribute( "hidden" );
-  QString context = element.attribute( "context" );
+  QString labelContext;
   QString label;
+  QString toolTipContext;
   QString toolTip;
+  QString whatsThisContext;
   QString whatsThis;
   QString defaultValue;
   QString code;
@@ -614,15 +629,15 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element, const Cf
     QString tag = e.tagName();
     if ( tag == "label" ) {
       label = e.text();
-      context = e.attribute( "context" );
+      labelContext = e.attribute( "context" );
     }
     else if ( tag == "tooltip" ) {
       toolTip = e.text();
-      context = e.attribute( "context" );
+      toolTipContext = e.attribute( "context" );
     }
     else if ( tag == "whatsthis" ) {
       whatsThis = e.text();
-      context = e.attribute( "context" );
+      whatsThisContext = e.attribute( "context" );
     }
     else if ( tag == "min" ) minValue = e.text();
     else if ( tag == "max" ) maxValue = e.text();
@@ -841,7 +856,7 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element, const Cf
     preProcessDefault(defaultValue, name, type, choices, code, cfg);
   }
 
-  CfgEntry *result = new CfgEntry( group, type, key, name, context, label, toolTip, whatsThis,
+  CfgEntry *result = new CfgEntry( group, type, key, name, labelContext, label, toolTipContext, toolTip, whatsThisContext, whatsThis,
                                    code, defaultValue, choices, signalList,
                                    hidden == "true" );
   if (!param.isEmpty())
@@ -946,7 +961,7 @@ QString defaultValue( const QString &t )
     else if ( type == "uint" )        return "0";
     else if ( type == "bool" )        return "false";
     else if ( type == "double" )      return "0.0";
-    else if ( type == "datedime" )    return "QDateTime()";
+    else if ( type == "datetime" )    return "QDateTime()";
     else if ( type == "longlong" )    return "0";
     else if ( type == "ulonglong" )   return "0";
     else if ( type == "intlist" )     return "QList<int>()";
@@ -1090,8 +1105,8 @@ QString userTextsFunctions( CfgEntry *e, const CfgConfig &cfg, QString itemVarSt
   if (itemVarStr.isNull()) itemVarStr=itemPath(e, cfg);
   if ( !e->label().isEmpty() ) {
     txt += "  " + itemVarStr + "->setLabel( ";
-    if ( !e->context().isEmpty() )
-      txt += "i18nc(" + quoteString(e->context()) + ", ";
+    if ( !e->labelContext().isEmpty() )
+      txt += "i18nc(" + quoteString(e->labelContext()) + ", ";
     else
       txt += "i18n(";
     if ( !e->param().isEmpty() )
@@ -1102,8 +1117,8 @@ QString userTextsFunctions( CfgEntry *e, const CfgConfig &cfg, QString itemVarSt
   }
   if ( !e->toolTip().isEmpty() ) {
     txt += "  " + itemVarStr + "->setToolTip( ";
-    if ( !e->context().isEmpty() )
-      txt += "i18nc(" + quoteString(e->context()) + ", ";
+    if ( !e->toolTipContext().isEmpty() )
+      txt += "i18nc(" + quoteString(e->toolTipContext()) + ", ";
     else
       txt += "i18n(";
     if ( !e->param().isEmpty() )
@@ -1114,8 +1129,8 @@ QString userTextsFunctions( CfgEntry *e, const CfgConfig &cfg, QString itemVarSt
   }
   if ( !e->whatsThis().isEmpty() ) {
     txt += "  " + itemVarStr + "->setWhatsThis( ";
-    if ( !e->context().isEmpty() )
-      txt += "i18nc(" + quoteString(e->context()) + ", ";
+    if ( !e->whatsThisContext().isEmpty() )
+      txt += "i18nc(" + quoteString(e->whatsThisContext()) + ", ";
     else
       txt += "i18n(";
     if ( !e->param().isEmpty() )
