@@ -183,7 +183,7 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
     if (!_untranslatedGenericName.isEmpty())
         entryMap.insert(QLatin1String("UntranslatedGenericName"), _untranslatedGenericName);
 
-    m_lstKeywords = desktopGroup.readEntry("Keywords", QStringList());
+    m_lstKeywords = desktopGroup.readXdgListEntry("Keywords", QStringList());
     entryMap.remove(QLatin1String("Keywords"));
     m_lstKeywords += desktopGroup.readEntry("X-KDE-Keywords", QStringList());
     entryMap.remove(QLatin1String("X-KDE-Keywords"));
@@ -416,6 +416,8 @@ bool KService::hasServiceType( const QString& serviceType ) const
 
     if (!d->m_bValid) return false; // (useless) safety test
     const KServiceType::Ptr ptr = KServiceType::serviceType( serviceType );
+    if (!ptr)
+        return false;
     const int serviceOffset = offset();
     // doesn't seem to work:
     //if ( serviceOffset == 0 )
@@ -974,6 +976,16 @@ void KService::setTerminalOptions(const QString &options)
     d->m_strTerminalOptions = options;
 }
 
+void KService::setExec(const QString& exec)
+{
+  Q_D(KService);
+
+  if (!exec.isEmpty()) {
+      d->m_strExec = exec;
+      d->path.clear();
+  }
+}
+
 QVector<KService::ServiceTypeAndPreference> & KService::_k_accessServiceTypes()
 {
     Q_D(KService);
