@@ -127,6 +127,15 @@ void KStandarddirsTest::testFindAllResources()
     QVERIFY( !cmakeModulesFiles.isEmpty() );
     QVERIFY( cmakeModulesFiles.count() > 80 ); // I have 150 here, installed by kdelibs.
 
+    // Create a local config file, the file will be used as expected result
+    const QString localConfigFile = m_kdehome + "/share/config/foorc";
+    QFile::remove(localConfigFile);
+    KConfig foorc("foorc");
+    KConfigGroup dummyGroup(&foorc, "Dummy");
+    dummyGroup.writeEntry("someEntry", true);
+    dummyGroup.sync();
+    QVERIFY2(QFile::exists(localConfigFile), qPrintable(localConfigFile));
+
     const QStringList configFiles = KGlobal::dirs()->findAllResources( "config" );
     QVERIFY( !configFiles.isEmpty() );
     QVERIFY( configFiles.count() > 5 ); // I have 9 here
@@ -152,8 +161,9 @@ void KStandarddirsTest::testFindAllResources()
     QStringList fileNames;
     const QStringList configFilesWithFilter = KGlobal::dirs()->findAllResources("config", "*rc", KStandardDirs::NoDuplicates, fileNames);
     QVERIFY( !configFilesWithFilter.isEmpty() );
-    QVERIFY( configFilesWithFilter.count() >= 4 );
     QVERIFY( oneEndsWith( configFilesWithFilter, "share/config/kdebugrc" ) );
+    QVERIFY( oneEndsWith( configFilesWithFilter, "kde-unit-test/share/config/foorc" ) );
+    QVERIFY2( configFilesWithFilter.count() >= 2, qPrintable(configFilesWithFilter.join(",")) );
     QVERIFY( !oneEndsWith( configFilesWithFilter, "share/config/ui/ui_standards.rc" ) ); // not recursive
     QVERIFY( !oneEndsWith( configFilesWithFilter, "share/config/accept-languages.codes" ) ); // didn't match the filter
     QCOMPARE(fileNames.count(), configFilesWithFilter.count());
@@ -162,12 +172,12 @@ void KStandarddirsTest::testFindAllResources()
 #if 0
     list = t.findAllResources("html", "en/*/index.html", false);
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toAscii().constData();
+        kDebug() << "docs " << (*it).toLatin1().constData();
     }
 
     list = t.findAllResources("html", "*/*/*.html", false);
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toAscii().constData();
+        kDebug() << "docs " << (*it).toLatin1().constData();
     }
 #endif
 }
@@ -221,19 +231,12 @@ void KStandarddirsTest::testFindExe()
     const QString kdeinit = KGlobal::dirs()->findExe( "kdeinit4" );
     QVERIFY( !kdeinit.isEmpty() );
 #ifdef Q_OS_MAC
-    QVERIFY( kdeinit.endsWith( "kdeinit4", PATH_SENSITIVITY ) );
+    QVERIFY2(kdeinit.endsWith("kdeinit4", PATH_SENSITIVITY), qPrintable(kdeinit));
 #else
-    QVERIFY( kdeinit.endsWith( "bin/kdeinit4" EXT, PATH_SENSITIVITY ) );
+    QVERIFY2(kdeinit.endsWith("bin/kdeinit4" EXT, PATH_SENSITIVITY), qPrintable(kdeinit));
 #endif
 
 
-#ifdef Q_OS_UNIX
-    // findExe with a result in libexec
-    const QString lnusertemp = KGlobal::dirs()->findExe( "lnusertemp" );
-    QVERIFY( !lnusertemp.isEmpty() );
-    QVERIFY( lnusertemp.endsWith( "lib" KDELIBSUFF "/kde4/libexec/lnusertemp" EXT, PATH_SENSITIVITY ) );
-#endif
-
 #ifndef Q_OS_MAC // kdeinit4 is a bundle on Mac, so the below doesn't work
     // Check the "exe" resource too
     QString kdeinitPath1 = KGlobal::dirs()->realFilePath(kdeinit);
@@ -242,8 +245,14 @@ void KStandarddirsTest::testFindExe()
 #endif
 
 #ifdef Q_OS_UNIX
-    QCOMPARE_PATHS( KGlobal::dirs()->realFilePath(lnusertemp),
-              KGlobal::dirs()->locate( "exe", "lnusertemp" ) );
+    // findExe with a result in libexec
+    const QString lnusertemp = KGlobal::dirs()->findExe( "lnusertemp" );
+    QVERIFY( !lnusertemp.isEmpty() );
+    QVERIFY( lnusertemp.endsWith( "lib" KDELIBSUFF "/kde4/libexec/lnusertemp" EXT, PATH_SENSITIVITY ) );
+
+    // locate("exe") with a result in libexec
+    const QString locateExeResult = KGlobal::dirs()->locate("exe", "lnusertemp");
+    QVERIFY(locateExeResult.endsWith("lib" KDELIBSUFF "/kde4/libexec/lnusertemp" EXT, PATH_SENSITIVITY));
 
     // findExe with relative path
     const QString pwd = QDir::currentPath();
