@@ -1099,14 +1099,14 @@ JSValue* DOMDocumentProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj
   case DOMDocument::CreateComment:
     return getDOMNode(exec,doc.createComment(s.implementation()));
   case DOMDocument::CreateCDATASection:
-    return getDOMNode(exec,doc.createCDATASection(s.implementation()));  /* TODO: okay ? */
+    return getDOMNode(exec,doc.createCDATASection(s.implementation(), exception));
   case DOMDocument::CreateProcessingInstruction:
     return getDOMNode(exec,doc.createProcessingInstruction(args[0]->toString(exec).domString(),
                               args[1]->toString(exec).domString().implementation()));
   case DOMDocument::CreateAttribute:
     return getDOMNode(exec,doc.createAttribute(s, exception));
   case DOMDocument::CreateEntityReference:
-    return getDOMNode(exec,doc.createEntityReference(args[0]->toString(exec).domString()));
+    return getDOMNode(exec,doc.createEntityReference(args[0]->toString(exec).domString(), exception));
   case DOMDocument::GetElementsByTagName:
     return getDOMNodeList(exec,doc.getElementsByTagName(s));
   case DOMDocument::ImportNode: // DOM2
