@@ -24,6 +24,7 @@
 #include "kdirlister.h"
 #include "kfileitem.h"
 #include "deletejob.h"
+#include "clipboardupdater_p.h"
 
 #include <klocale.h>
 #include <kdesktopfile.h>
@@ -221,6 +222,7 @@ public:
 
     void slotStart();
     void slotEntries( KIO::Job*, const KIO::UDSEntryList& list );
+    void slotSubError(KIO::ListJob* job, KIO::ListJob *subJob);
     void addCopyInfoFromUDSEntry(const UDSEntry& entry, const KUrl& srcUrl, bool srcIsDir, const KUrl& currentDest);
     /**
      * Forward signal from subjob
@@ -256,6 +258,7 @@ CopyJob::CopyJob(CopyJobPrivate &dd)
 {
     setProperty("destUrl", d_func()->m_dest.url());
     QTimer::singleShot(0, this, SLOT(slotStart()));
+    qRegisterMetaType<KIO::UDSEntry>("KIO::UDSEntry");
 }
 
 CopyJob::~CopyJob()
@@ -337,8 +340,14 @@ void CopyJobPrivate::slotResultStating( KJob *job )
     if ( destinationState == DEST_NOT_STATED ) {
         if ( m_dest.isLocalFile() ) { //works for dirs as well
             QString path = m_dest.toLocalFile();
+            if (m_asMethod) {
+                // In copy-as mode, we want to check the directory to which we're
+                // copying. The target file or directory does not exist yet, which
+                // might confuse KDiskFreeSpaceInfo.
+                path = QFileInfo(path).absolutePath();
+            }
             KFileSystemType::Type fsType = KFileSystemType::fileSystemType( path );
-            if ( fsType != KFileSystemType::Nfs && fsType != KFileSystemType::Smb ) {
+            if ( fsType != KFileSystemType::Nfs && fsType != KFileSystemType::Smb  && fsType != KFileSystemType::Ramfs ) {
                 m_freeSpace = KDiskFreeSpaceInfo::freeSpaceInfo( path ).available();
             }
             //TODO actually preliminary check is even more valuable for slow NFS/SMB mounts,
@@ -558,6 +567,18 @@ void CopyJobPrivate::slotEntries(KIO::Job* job, const UDSEntryList& list)
     }
 }
 
+void CopyJobPrivate::slotSubError(ListJob* job, ListJob* subJob)
+{
+	const KUrl url = subJob->url();
+	kWarning() << url << subJob->errorString();
+
+	Q_Q(CopyJob);
+
+	emit q->warning(job, subJob->errorString(), QString());
+	skip(url, true);
+}
+
+
 void CopyJobPrivate::addCopyInfoFromUDSEntry(const UDSEntry& entry, const KUrl& srcUrl, bool srcIsDir, const KUrl& currentDest)
 {
     struct CopyInfo info;
@@ -765,7 +786,8 @@ void CopyJobPrivate::statCurrentSrc()
         // entries for UDS_USER and UDS_GROUP even on initially empty UDSEntries (#192185)
         if (entry.contains(KIO::UDSEntry::UDS_NAME)) {
             kDebug(7007) << "fast path! found info about" << m_currentSrcURL << "in KDirLister";
-            sourceStated(entry, m_currentSrcURL);
+            // sourceStated(entry, m_currentSrcURL); // don't recurse, see #319747, use queued invokeMethod instead
+            QMetaObject::invokeMethod(q, "sourceStated", Qt::QueuedConnection, Q_ARG(KIO::UDSEntry, entry), Q_ARG(KUrl, m_currentSrcURL));
             return;
         }
 
@@ -849,6 +871,8 @@ void CopyJobPrivate::startListing( const KUrl & src )
     newjob->setUnrestricted(true);
     q->connect(newjob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
                SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
+    q->connect(newjob, SIGNAL(subError(KIO::ListJob*,KIO::ListJob*)),
+	       SLOT(slotSubError(KIO::ListJob*,KIO::ListJob*)));
     q->addSubjob( newjob );
 }
 
@@ -1725,6 +1749,7 @@ void CopyJob::emitResult()
     // Even if some error made us abort midway, we might still have done
     // part of the job so we better update the views! (#118583)
     if (!d->m_bOnlyRenames) {
+        // If only renaming happened, KDirNotify::FileRenamed was emitted by the rename jobs
         KUrl url(d->m_globalDest);
         if (d->m_globalDestinationState != DEST_IS_DIR || d->m_asMethod)
             url.setPath(url.directory());
@@ -1735,12 +1760,12 @@ void CopyJob::emitResult()
             kDebug(7007) << "KDirNotify'ing FilesRemoved" << d->m_successSrcList.toStringList();
             org::kde::KDirNotify::emitFilesRemoved(d->m_successSrcList.toStringList());
         }
+    }
 
-        // Re-enable watching on the dirs that held the deleted files
-        if (d->m_mode == CopyJob::Move) {
-            for (QSet<QString>::const_iterator it = d->m_parentDirs.constBegin() ; it != d->m_parentDirs.constEnd() ; ++it)
-                KDirWatch::self()->restartDirScan( *it );
-        }
+    // Re-enable watching on the dirs that held the deleted/moved files
+    if (d->m_mode == CopyJob::Move) {
+        for (QSet<QString>::const_iterator it = d->m_parentDirs.constBegin() ; it != d->m_parentDirs.constEnd() ; ++it)
+            KDirWatch::self()->restartDirScan( *it );
     }
     Job::emitResult();
 }
@@ -2161,7 +2186,9 @@ CopyJob *KIO::move(const KUrl& src, const KUrl& dest, JobFlags flags)
     //kDebug(7007) << src << dest;
     KUrl::List srcList;
     srcList.append( src );
-    return CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, false, flags);
+    CopyJob* job = CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, false, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::moveAs(const KUrl& src, const KUrl& dest, JobFlags flags)
@@ -2169,13 +2196,17 @@ CopyJob *KIO::moveAs(const KUrl& src, const KUrl& dest, JobFlags flags)
     //kDebug(7007) << src << dest;
     KUrl::List srcList;
     srcList.append( src );
-    return CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, true, flags);
+    CopyJob* job = CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, true, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::move( const KUrl::List& src, const KUrl& dest, JobFlags flags)
 {
     //kDebug(7007) << src << dest;
-    return CopyJobPrivate::newJob(src, dest, CopyJob::Move, false, flags);
+    CopyJob* job = CopyJobPrivate::newJob(src, dest, CopyJob::Move, false, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::link(const KUrl& src, const KUrl& destDir, JobFlags flags)
