@@ -23,6 +23,7 @@
 
 #include <QDir>
 #include <QMap>
+#include <QMutableListIterator>
 #include <QFileInfo>
 
 #include <kconfiggroup.h>
@@ -140,7 +141,7 @@ PackageStructure::Ptr PackageStructure::load(const QString &packageFormat)
     } else if (packageFormat == "Plasma/Generic") {
         structure = defaultPackageStructure(GenericComponent);
         structure->d->type = "Plasma/Generic";
-        structure->setDefaultPackageRoot(KStandardDirs::locate("data", "plasma/packages/"));
+        structure->setDefaultPackageRoot("plasma/packages/");
     }
 
     if (structure) {
@@ -483,7 +484,7 @@ void PackageStructure::read(const KConfigBase *config)
     QStringList groups = config->groupList();
     foreach (const QString &group, groups) {
         KConfigGroup entry(config, group);
-        QByteArray key = group.toAscii();
+        QByteArray key = group.toLatin1();
 
         QString path = entry.readEntry("Path", QString());
         QString name = entry.readEntry("Name", QString());
@@ -548,6 +549,17 @@ QStringList PackageStructure::contentsPrefixPaths() const
 void PackageStructure::setContentsPrefixPaths(const QStringList &prefixPaths)
 {
     d->contentsPrefixPaths = prefixPaths;
+
+    // the code assumes that the prefixes have a trailing slash
+    // so let's make that true here
+    QMutableStringListIterator it(d->contentsPrefixPaths);
+    while (it.hasNext()) {
+        it.next();
+
+        if (!it.value().endsWith('/')) {
+            it.setValue(it.value() % '/');
+        }
+    }
 }
 
 bool PackageStructure::installPackage(const QString &package, const QString &packageRoot)
@@ -615,6 +627,7 @@ PackageMetadata PackageStructure::metadata()
             if (mimetype->is("application/zip")) {
                 archive = new KZip(d->path);
             } else if (mimetype->is("application/x-compressed-tar") || mimetype->is("application/x-gzip") ||
+                       mimetype->is("application/x-xz-compressed-tar") || mimetype->is("application/x-lzma-compressed-tar") ||
                        mimetype->is("application/x-tar")|| mimetype->is("application/x-bzip-compressed-tar")) {
                 archive = new KTar(d->path);
             } else {
